Skip to contents

[Stable]

Create an additive (lambda) error model

Usage

additive(initial, coeff, fixed = FALSE, outeq = 1)

Arguments

initial

Initial value for lambda

coeff

Vector of coefficients defining assay error polynomial

fixed

Estimate if FALSE (default).

outeq

The output equation this error model applies to, given either as the number used in the model's out block (e.g. outeq = 2 for Y[2]) or as an output label declared in a DSL model. Defaults to 1.