Skip to contents

lit_sim(), model_lib(), and pm_plot() launch standalone golem app packages.

Usage

lit_sim(launch.browser = TRUE)

pm_plot(launch.browser = TRUE, data_env = .GlobalEnv)

apps(launch.browser = TRUE)

Arguments

launch.browser

Logical. Should the app launch in a browser?

data_env

Environment passed to pm_plot() containing the data objects the app should discover and use. Defaults to .GlobalEnv. Ignored by launchers that do not accept this argument.

Value

Invisibly returns the value from the standalone app package's run_app() function for launcher functions. apps() returns invisibly NULL on cancel/invalid input.

Details

apps() shows an interactive numbered menu (via cli) and launches the selected app using readline() input.