Performs an on-demand check for newer Pmetrics and R releases.
This function is intended for interactive use and avoids running network
checks automatically during package attach.
Usage
check_updates(verbose = interactive(), timeout = 2)
Performs an on-demand check for newer Pmetrics and R releases.
This function is intended for interactive use and avoids running network
checks automatically during package attach.
check_updates(verbose = interactive(), timeout = 2)