Skip to contents

[Stable] Retrieves metadata for the latest R release available for the current platform from the r-hub rversions API.

Usage

latestR()

Value

A list containing all fields returned by the API response.