Plots the raw data (
class: PM_cycle_data) from a PM_cycle object in the same way as plotting a PM_cycle object.
Both use plot.PM_cycle.
Usage
# S3 method for class 'PM_cycle_data'
plot(x, ...)Arguments
- x
A
PM_cycle_dataobject- ...
Additional arguments passed to plot.PM_cycle
Examples
# There is no example we can think of to filter or otherwise process a PM_cycle object,
# but we provide this function for completeness.
NPex$cycle$data |> plot()