Skip to contents

[Stable] Allows plotting of altered PM_data objects.

Usage

# S3 method for class 'PM_data_data'
plot(x, ...)

Arguments

x

A data frame in the format of the standard_data field of a PM_data object

...

Additional arguments passed to plot.PM_data

Value

A plot of the data.

Details

This is useful if you want to modify the data in a PM_data object, e.g. to filter the data, but still want to use the plotting capabilities of plot.PM_data. See plot.PM_data for details on how to format the plot.

See also

Author

Michael Neely

Examples

if (FALSE) { # \dontrun{
# filter then plot the standard_data data frame from a PM_data object
dataEx$standard_data %>% filter(gender == 0) %>% plot()
} # }