Skip to contents

[Stable] Summarizes the raw data (class: PM_cycle_data) from a PM_cycle object in the same way as summarizing a PM_cycle object. Both use summary.PM_cycle.

Usage

# S3 method for class 'PM_cycle_data'
summary(object, ...)

Arguments

object

A PM_cycle_data object

...

Additional arguments passed to summary.PM_cycle

Examples

# There is no example we can think of to filter or otherwise process a PM_cycle object,
# but we provide this function for completeness.
NPex$cycle$data |> summary()
#> 
#> ── Cycle Summary ──
#> 
#> Cycle number: 100 of 100
#> Status: Stopped (maximum cycles reached)
#> Log-likelihood: 451.101
#> AIC:: 459.101
#> BIC: 463.084
#> Outeq 1: Gamma = 1.314
#> 
#> ── Normalized parameter values: 
#> # A tibble: 3 × 6
#>   cycle    ka    ke     v tlag1 stat  
#>   <dbl> <dbl> <dbl> <dbl> <dbl> <chr> 
#> 1   100 0.994  1.16  1.07 0.592 mean  
#> 2   100 5.51   1.40  1.01 2.10  sd    
#> 3   100 1.19   1.07  1.17 0.581 median
# all the below are the same
# summary(NPex$cycle$data)
# summary(NPex$cycle)
# NPex$cycle$summary()