Arguments
- x
- template
Report mode. One of
"app","plotly","ggplot", or"none". If omitted, uses thereport_templatePmetrics option. An invalid value falls back to that saved default.- path
Output directory for HTML reports.
- show
Controls whether the report should be opened automatically, defaults to
TRUE.- quiet
Suppress output from HTML report rendering.
Value
Invisibly returns 1 on success, 0 when reporting is disabled,
and -1 when no report can be generated.