Skip to contents

[Stable]

Launches the Pmetrics reporting app for a completed run

Usage

PM_report(x, template, path, show = TRUE, quiet = TRUE)

Arguments

x

A PM_result object obtained from PM_load.

template

Deprecated for app mode. Used only for HTML fallback report generation when app launch fails.

path

Deprecated for app mode. Used only for HTML fallback report generation when app launch fails.

show

Controls whether the Shiny app should be opened automatically, defaults to TRUE.

quiet

Retained for compatibility.

Value

Launches the Pmetrics reporting app.

See also

Author

Markus Hovd, Julian Otalvaro, and Michael Neely