Arguments
- initial
Initial value for lambda
- coeff
Vector of coefficients defining assay error polynomial
- fixed
Estimate if
FALSE(default).- outeq
The output equation this error model applies to, given either as the number used in the model's
outblock (e.g.outeq = 2forY[2]) or as an output label declared in a DSL model. Defaults to1.