R/PMutilities.R
latestR.Rd
Retrieves metadata for the latest R release available for the current platform from the r-hub rversions API.
latestR()
A list containing all fields returned by the API response.