Allows plotting of altered PM_data objects.
Usage
# S3 method for class 'PM_data_data'
plot(x, ...)Arguments
- x
A data frame in the format of the
standard_datafield of a PM_data object- ...
Additional arguments passed to plot.PM_data
Details
This is useful if you want to modify the data in a PM_data object, e.g. to filter the data, but still want to use the plotting capabilities of plot.PM_data. See plot.PM_data for details on how to format the plot.